@@ -27,6 +27,8 @@
 #include <com/sun/star/beans/Pair.hpp>
 #include <com/sun/star/embed/XRelationshipAccess.hpp>
 #include <com/sun/star/frame/XModel.hpp>
+#include <com/sun/star/text/XTextDocument.hpp>
+#include <com/sun/star/util/DateTimeWithTimezone.hpp>
 #include <com/sun/star/xml/sax/XFastSAXSerializable.hpp>
 #include <com/sun/star/xml/sax/XSAXSerializable.hpp>
 #include <com/sun/star/xml/sax/Writer.hpp>
@@ -153,6 +155,7 @@ const Sequence< beans::Pair< OUString, sal_Int32 > >& NamespaceIds()
              NMSP_xr16},
             {u"http://schemas.microsoft.com/office/drawing/2017/decorative"_ustr, NMSP_adec},
             {u"http://schemas.microsoft.com/office/drawing/2016/SVG/main"_ustr, NMSP_asvg},
+            {u"http://schemas.microsoft.com/office/drawing/2014/chartex"_ustr, NMSP_cx},
         };
     return SINGLETON;
 };
@@ -200,7 +203,8 @@ XmlFilterBase::XmlFilterBase( const Reference< XComponentContext >& rxContext )
     FilterBase( rxContext ),
     mxImpl( new XmlFilterBaseImpl ),
     mnRelId( 1 ),
-    mnMaxDocId( 0 ),
+    // mnMaxDocId has to start from 1, Word doesn't accept id 0 for eg. grouped shapes
+    mnMaxDocId( 1 ),
     mbMSO2007(false),
     mbMSO(false),
     mbMissingExtDrawing(false)
@@ -506,9 +510,10 @@ Reference< XOutputStream > XmlFilterBase::openFragmentStream( const OUString& rS
     return xOutputStream;
 }
 
-FSHelperPtr XmlFilterBase::openFragmentStreamWithSerializer( const OUString& rStreamName, const OUString& rMediaType )
+FSHelperPtr XmlFilterBase::openFragmentStreamWithSerializer(
+        const OUString& rStreamName, const OUString& rMediaType, bool bNoHeader /* = false */)
 {
-    const bool bWriteHeader = rMediaType.indexOf( "vml" ) < 0 || rMediaType.indexOf( "+xml" ) >= 0;
+    const bool bWriteHeader = !bNoHeader && (rMediaType.indexOf( "vml" ) < 0 || rMediaType.indexOf( "+xml" ) >= 0);
     return std::make_shared<FastSerializerHelper>( openFragmentStream( rStreamName, rMediaType ), bWriteHeader );
 }
 
@@ -562,6 +567,15 @@ OUString XmlFilterBase::addRelation( const Reference< XOutputStream >& rOutputSt
     return OUString();
 }
 
+static bool lcl_isValidDate(const util::DateTime& rTime)
+{
+    if (rTime.Year == 0)
+        return false;
+
+    // MS Office reports document as corrupt if core.xml contains any Year <= 1600 or > 9999
+    return rTime.Year > 1600  && rTime.Year < 10000;
+}
+
 static void
 writeElement( const FSHelperPtr& pDoc, sal_Int32 nXmlElement, std::u16string_view sValue )
 {
@@ -599,6 +613,31 @@ writeElement( const FSHelperPtr& pDoc, sal_Int32 nXmlElement, const util::DateTi
     pDoc->endElement( nXmlElement );
 }
 
+static void
+writeElement( const FSHelperPtr& pDoc, sal_Int32 nXmlElement, const util::DateTimeWithTimezone& rTime )
+{
+    if (rTime.Timezone == 0)
+    {
+        writeElement(pDoc, nXmlElement, rTime.DateTimeInTZ);
+        return;
+    }
+
+    if( rTime.DateTimeInTZ.Year == 0 )
+        return;
+
+    if ( ( nXmlElement >> 16 ) != XML_dcterms )
+        pDoc->startElement(nXmlElement);
+    else
+        pDoc->startElement(nXmlElement, FSNS(XML_xsi, XML_type), "dcterms:W3CDTF");
+
+    OStringBuffer aStr;
+    sax::Converter::convertDateTime(aStr, rTime.DateTimeInTZ, &rTime.Timezone);
+
+    pDoc->write( aStr );
+
+    pDoc->endElement( nXmlElement );
+}
+
 static void
 writeElement( const FSHelperPtr& pDoc, sal_Int32 nXmlElement, const Sequence< OUString >& aItems )
 {
@@ -632,17 +671,12 @@ writeCoreProperties( XmlFilterBase& rSelf, const Reference< XDocumentProperties
         = bRemovePersonalInfo
           && !SvtSecurityOptions::IsOptionSet(SvtSecurityOptions::EOption::DocWarnKeepDocUserInfo);
 
-    OUString sValue;
-    if( rSelf.getVersion() == oox::core::ISOIEC_29500_2008  )
-    {
-        // The lowercase "officedocument" is intentional and according to the spec
-        // (although most other places are written "officeDocument")
-        sValue = "http://schemas.openxmlformats.org/officedocument/2006/relationships/metadata/core-properties";
-    }
-    else
-        sValue = "http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties";
-
-    rSelf.addRelation( sValue, u"docProps/core.xml" );
+    // Although the spec says that ISOIEC_29500_2008 must use the "officedocument" URI for core.xml,
+    // MS errata admits that MS Office just uses the old "package" URI from ECMA_376_1ST_EDITION.
+    // Tested with Office 2024 - and even "Strict Open XML" uses "package".
+    rSelf.addRelation(
+        u"http://schemas.openxmlformats.org/package/2006/relationships/metadata/core-properties"_ustr,
+        u"docProps/core.xml");
     FSHelperPtr pCoreProps = rSelf.openFragmentStreamWithSerializer(
             u"docProps/core.xml"_ustr,
             u"application/vnd.openxmlformats-package.core-properties+xml"_ustr );
@@ -682,7 +716,9 @@ writeCoreProperties( XmlFilterBase& rSelf, const Reference< XDocumentProperties
     }
     if (!bRemoveUserInfo)
     {
-        writeElement(pCoreProps, FSNS(XML_dcterms, XML_created), xProperties->getCreationDate());
+        const util::DateTime aCreateDate = xProperties->getCreationDate();
+        if (lcl_isValidDate(aCreateDate))
+            writeElement(pCoreProps, FSNS(XML_dcterms, XML_created), aCreateDate);
         writeElement(pCoreProps, FSNS(XML_dc, XML_creator), xProperties->getAuthor());
     }
     writeElement( pCoreProps, FSNS( XML_dc, XML_description ),      xProperties->getDescription() );
@@ -700,9 +736,13 @@ writeCoreProperties( XmlFilterBase& rSelf, const Reference< XDocumentProperties
     if (!bRemoveUserInfo)
     {
         writeElement(pCoreProps, FSNS(XML_cp, XML_lastModifiedBy), xProperties->getModifiedBy());
-        writeElement(pCoreProps, FSNS(XML_cp, XML_lastPrinted), xProperties->getPrintDate());
-        writeElement(pCoreProps, FSNS(XML_dcterms, XML_modified),
-                     xProperties->getModificationDate());
+        const util::DateTime aPrintDate = xProperties->getPrintDate();
+        if (lcl_isValidDate(aPrintDate))
+            writeElement(pCoreProps, FSNS(XML_cp, XML_lastPrinted), aPrintDate);
+
+        const util::DateTime aModifyDate = xProperties->getModificationDate();
+        if (lcl_isValidDate(aModifyDate))
+            writeElement(pCoreProps, FSNS(XML_dcterms, XML_modified), aModifyDate);
     }
     if (!bRemovePersonalInfo)
     {
@@ -764,7 +804,7 @@ writeAppProperties( XmlFilterBase& rSelf, const Reference< XDocumentProperties >
     writeElement( pAppProps, XML_Notes,                 "notes" );
 #endif  /* def OOXTODO */
     // EditingDuration is in seconds, TotalTime is in minutes.
-    if (!bRemovePersonalInfo)
+    if (!bRemovePersonalInfo && !SvtSecurityOptions::IsOptionSet(SvtSecurityOptions::EOption::DocWarnRemoveEditingTimeInfo))
         writeElement(pAppProps, XML_TotalTime, xProperties->getEditingDuration() / 60);
 #ifdef OOXTODO
     writeElement( pAppProps, XML_HiddenSlides,          "hidden slides" );
@@ -941,6 +981,7 @@ writeCustomProperties( XmlFilterBase& rSelf, const Reference< XDocumentPropertie
                     util::Date aDate;
                     util::Duration aDuration;
                     util::DateTime aDateTime;
+                    util::DateTimeWithTimezone aDateTimeTZ;
                     if ( rProp.Value >>= num )
                     {
                         // i4 - 4-byte signed integer
@@ -960,6 +1001,8 @@ writeCustomProperties( XmlFilterBase& rSelf, const Reference< XDocumentPropertie
                     }
                     else if ( rProp.Value >>= aDateTime )
                             writeElement( pAppProps, FSNS( XML_vt, XML_filetime ), aDateTime );
+                    else if ( rProp.Value >>= aDateTimeTZ )
+                            writeElement( pAppProps, FSNS( XML_vt, XML_filetime ), aDateTimeTZ );
                     else
                         //no other options
                         OSL_FAIL( "XMLFilterBase::writeCustomProperties unsupported value type!" );
