@@ -57,7 +57,6 @@
 #include <com/sun/star/lang/XInitialization.hpp>
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/chart/ChartDataRowSource.hpp>
-#include <cppuhelper/bootstrap.hxx>
 #include <svtools/dialogclosedlistener.hxx>
 #include <officecfg/Office/Common.hxx>
 
@@ -138,7 +137,7 @@ void lcl_ChartInit(const uno::Reference <embed::XEmbeddedObject>& xObj, ScViewDa
     }
     else
     {
-        xDataProvider.set(new ScChart2DataProvider(&rScDoc));
+        xDataProvider = new ScChart2DataProvider(&rScDoc);
     }
 
     xReceiver->attachDataProvider(xDataProvider);
@@ -217,8 +216,8 @@ void lcl_ChartInit(const uno::Reference <embed::XEmbeddedObject>& xObj, ScViewDa
 }
 
 FuInsertOLE::FuInsertOLE(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawView* pViewP,
-           SdrModel* pDoc, SfxRequest& rReq)
-    : FuPoor(rViewSh, pWin, pViewP, pDoc, rReq)
+           SdrModel& rDoc, SfxRequest& rReq)
+    : FuPoor(rViewSh, pWin, pViewP, rDoc, rReq)
 {
     if( ! rReq.IsAPI() )
         rReq.Done();
@@ -355,7 +354,7 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawView*
                 aPnt.AdjustX( -(aSize.Width()) );      // move position to left edge
             tools::Rectangle aRect (aPnt, aSize);
             rtl::Reference<SdrOle2Obj> pObj = new SdrOle2Obj(
-                *pDoc, // TTTT should be reference
+                rDoc,
                 aObjRef,
                 aName,
                 aRect);
@@ -411,8 +410,8 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawView*
 }
 
 FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawView* pViewP,
-                             SdrModel* pDoc, SfxRequest& rReq, const Link<css::ui::dialogs::DialogClosedEvent*, void>& rLink)
-    : FuPoor(rViewSh, pWin, pViewP, pDoc, rReq)
+                             SdrModel& rDoc, SfxRequest& rReq, const Link<css::ui::dialogs::DialogClosedEvent*, void>& rLink)
+    : FuPoor(rViewSh, pWin, pViewP, rDoc, rReq)
 {
     const SfxItemSet* pReqArgs = rReq.GetArgs();
 
@@ -504,24 +503,28 @@ FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawV
         xChartModel->lockControllers();
 
     // object size
-    awt::Size aSz = xObj->getVisualAreaSize( nAspect );
-    Size aSize( aSz.Width, aSz.Height );
-
-    MapUnit aMapUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) );
-
-    bool bSizeCh = false;
-    if (aSize.IsEmpty())
+    Size aSize;
+    if (xObj.is())
     {
-        aSize.setWidth( 5000 );
-        aSize.setHeight( 5000 );
-        bSizeCh = true;
-    }
-    if (bSizeCh)
-    {
-        aSize = OutputDevice::LogicToLogic( aSize, MapMode( MapUnit::Map100thMM ), MapMode( aMapUnit ) );
-        aSz.Width = aSize.Width();
-        aSz.Height = aSize.Height();
-        xObj->setVisualAreaSize( nAspect, aSz );
+        awt::Size aSz = xObj->getVisualAreaSize( nAspect );
+        aSize = Size( aSz.Width, aSz.Height );
+
+        MapUnit aMapUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) );
+
+        bool bSizeCh = false;
+        if (aSize.IsEmpty())
+        {
+            aSize.setWidth( 5000 );
+            aSize.setHeight( 5000 );
+            bSizeCh = true;
+        }
+        if (bSizeCh)
+        {
+            aSize = OutputDevice::LogicToLogic( aSize, MapMode( MapUnit::Map100thMM ), MapMode( aMapUnit ) );
+            aSz.Width = aSize.Width();
+            aSz.Height = aSize.Height();
+            xObj->setVisualAreaSize( nAspect, aSz );
+        }
     }
 
     ScViewData& rData = rViewSh.GetViewData();
@@ -568,7 +571,7 @@ FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawV
                 if (bUndo)
                 {
                     pScDocSh->GetUndoManager()->AddUndoAction(
-                        std::make_unique<ScUndoInsertTab>( pScDocSh, nNewTab,
+                        std::make_unique<ScUndoInsertTab>( *pScDocSh, nNewTab,
                                              true/*bAppend*/, aTabName ) );
                 }
 
@@ -596,7 +599,7 @@ FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawV
 
     tools::Rectangle aRect (aStart, aSize);
     rtl::Reference<SdrOle2Obj> pObj = new SdrOle2Obj(
-        *pDoc, // TTTT should be reference
+        rDoc,
         svt::EmbeddedObjectRef(xObj, nAspect),
         aName,
         aRect);
@@ -628,9 +631,7 @@ FuInsertChart::FuInsertChart(ScTabViewShell& rViewSh, vcl::Window* pWin, ScDrawV
             rViewShell.ActivateObject(pObj.get(), embed::EmbedVerbs::MS_OLEVERB_SHOW);
 
         //open wizard
-        //@todo get context from calc if that has one
-        uno::Reference< uno::XComponentContext > xContext(
-            ::cppu::defaultBootstrap_InitialComponentContext() );
+        uno::Reference< uno::XComponentContext > xContext(::comphelper::getProcessComponentContext());
         if(xContext.is())
         {
             uno::Reference< lang::XMultiComponentFactory > xMCF( xContext->getServiceManager() );
