@@ -231,7 +231,7 @@ void SwNoTextFrame::PaintSwFrame(vcl::RenderContext& rRenderContext, SwRect cons
             if ( aText.isEmpty() && pNd->IsGrfNode() )
                 GetRealURL( *static_cast<const SwGrfNode*>(pNd), aText );
             if( aText.isEmpty() )
-                aText = FindFlyFrame()->GetFormat()->GetName();
+                aText = FindFlyFrame()->GetFormat()->GetName().toString();
             lcl_PaintReplacement( getFrameArea(), aText, *pSh, this, false );
         }
         return;
@@ -756,95 +756,97 @@ void SwNoTextFrame::SwClientNotify(const SwModify& rModify, const SfxHint& rHint
             InvalidatePrt();
             SetCompletePaint();
         }
-        return;
     }
-    if(rHint.GetId() == SfxHintId::SwPreGraphicArrived
+    else if(rHint.GetId() == SfxHintId::SwPreGraphicArrived
             || rHint.GetId() == SfxHintId::SwGraphicPieceArrived
             || rHint.GetId() == SfxHintId::SwLinkedGraphicStreamArrived)
     {
         OnGraphicArrived();
-        return;
     }
     else if (rHint.GetId() == SfxHintId::SwFormatChange)
     {
         ClearCache();
         InvalidatePrt();
         SetCompletePaint();
-        return;
     }
-    else if (rHint.GetId() != SfxHintId::SwLegacyModify)
-        return;
-    auto pLegacy = static_cast<const sw::LegacyModifyHint*>(&rHint);
-    sal_uInt16 nWhich = pLegacy->GetWhich();
-
-    SwContentFrame::SwClientNotify(rModify, rHint);
-
-    switch( nWhich )
+    else if (rHint.GetId() == SfxHintId::SwAttrSetChange)
     {
-    case RES_OBJECTDYING:
-        break;
+        auto pChangeHint = static_cast<const sw::AttrSetChangeHint*>(&rHint);
+        SwContentFrame::SwClientNotify(rModify, rHint);
 
-    case RES_UPDATE_ATTR:
-        if (GetNode()->GetNodeType() != SwNodeType::Grf) {
-            break;
-        }
-        ClearCache();
-        break;
+        sal_uInt16 n;
+        for( n = RES_GRFATR_BEGIN; n < RES_GRFATR_END; ++n )
+            if( SfxItemState::SET == pChangeHint->m_pOld->GetChgSet()->
+                            GetItemState( n, false ))
+            {
+                ClearCache();
 
-    case RES_ATTRSET_CHG:
-        {
-            sal_uInt16 n;
-            for( n = RES_GRFATR_BEGIN; n < RES_GRFATR_END; ++n )
-                if( SfxItemState::SET == static_cast<const SwAttrSetChg*>(pLegacy->m_pOld)->GetChgSet()->
-                                GetItemState( n, false ))
+                if(RES_GRFATR_ROTATION == n)
                 {
-                    ClearCache();
-
-                    if(RES_GRFATR_ROTATION == n)
+                    // RotGrfFlyFrame: Update Handles in view, these may be rotation-dependent
+                    // (e.g. crop handles) and need a visualisation update
+                    if ( GetNode()->GetNodeType() == SwNodeType::Grf )
                     {
-                        // RotGrfFlyFrame: Update Handles in view, these may be rotation-dependent
-                        // (e.g. crop handles) and need a visualisation update
-                        if ( GetNode()->GetNodeType() == SwNodeType::Grf )
+                        SwGrfNode* pNd = static_cast<SwGrfNode*>( GetNode());
+                        SwViewShell *pVSh = pNd->GetDoc().getIDocumentLayoutAccess().GetCurrentViewShell();
+
+                        if(pVSh)
                         {
-                            SwGrfNode* pNd = static_cast<SwGrfNode*>( GetNode());
-                            SwViewShell *pVSh = pNd->GetDoc().getIDocumentLayoutAccess().GetCurrentViewShell();
+                            SdrView* pDrawView = pVSh->GetDrawView();
 
-                            if(pVSh)
+                            if(pDrawView)
                             {
-                                SdrView* pDrawView = pVSh->GetDrawView();
-
-                                if(pDrawView)
-                                {
-                                    pDrawView->AdjustMarkHdl(nullptr);
-                                }
+                                pDrawView->AdjustMarkHdl(nullptr);
                             }
-
-                            // RotateFlyFrame3 - invalidate needed for ContentFrame (inner, this)
-                            // and LayoutFrame (outer, GetUpper). It is possible to only invalidate
-                            // the outer frame, but that leads to an in-between state that gets
-                            // potentially painted
-                            if(GetUpper())
-                            {
-                                GetUpper()->InvalidateAll_();
-                            }
-
-                            InvalidateAll_();
                         }
-                    }
-                    break;
-                }
-            if( RES_GRFATR_END == n )           // not found
-                return ;
-        }
-        break;
 
-    default:
+                        // RotateFlyFrame3 - invalidate needed for ContentFrame (inner, this)
+                        // and LayoutFrame (outer, GetUpper). It is possible to only invalidate
+                        // the outer frame, but that leads to an in-between state that gets
+                        // potentially painted
+                        if(GetUpper())
+                        {
+                            GetUpper()->InvalidateAll_();
+                        }
+
+                        InvalidateAll_();
+                    }
+                }
+                break;
+            }
+        if( RES_GRFATR_END == n )           // not found
+            return ;
+
+        InvalidatePrt();
+        SetCompletePaint();
+    }
+    else if (rHint.GetId() == SfxHintId::SwObjectDying)
+    {
+        SwContentFrame::SwClientNotify(rModify, rHint);
+        InvalidatePrt();
+        SetCompletePaint();
+    }
+    else if (rHint.GetId() == SfxHintId::SwUpdateAttr)
+    {
+        SwContentFrame::SwClientNotify(rModify, rHint);
+        if (GetNode()->GetNodeType() == SwNodeType::Grf)
+            ClearCache();
+        InvalidatePrt();
+        SetCompletePaint();
+    }
+    else if (rHint.GetId() == SfxHintId::SwLegacyModify)
+    {
+        auto pLegacy = static_cast<const sw::LegacyModifyHint*>(&rHint);
+        sal_uInt16 nWhich = pLegacy->GetWhich();
+
+        SwContentFrame::SwClientNotify(rModify, rHint);
+
         if ( !pLegacy->m_pNew || !isGRFATR(nWhich) )
             return;
-    }
 
-    InvalidatePrt();
-    SetCompletePaint();
+        InvalidatePrt();
+        SetCompletePaint();
+    }
 }
 
 static void lcl_correctlyAlignRect( SwRect& rAlignedGrfArea, const SwRect& rInArea, vcl::RenderContext const * pOut )
@@ -1183,7 +1185,7 @@ void SwNoTextFrame::PaintPicture( vcl::RenderContext* pOut, const SwRect &rGrfAr
 void SwNoTextFrame::ImplPaintPictureGraphic( vcl::RenderContext* pOut,
     SwGrfNode* pGrfNd, bool bPrn,
     const SwRect& rAlignedGrfArea, SwViewShell* pShell,
-    SwNoTextNode& rNoTNd ) const
+    const SwNoTextNode& rNoTNd ) const
 {
     bool bContinue = true;
     const GraphicObject& rGrfObj = pGrfNd->GetGrfObj(bPrn);
@@ -1296,7 +1298,7 @@ void SwNoTextFrame::ImplPaintPictureGraphic( vcl::RenderContext* pOut,
                 *pOut,
                 aPrimitives,
                 aGraphicTransform,
-                nullptr == pGrfNd->GetFlyFormat() ? OUString() : pGrfNd->GetFlyFormat()->GetName(),
+                nullptr == pGrfNd->GetFlyFormat() ? OUString() : pGrfNd->GetFlyFormat()->GetName().toString(),
                 rNoTNd.GetTitle(),
                 rNoTNd.GetDescription());
             bSucceeded = true;
@@ -1314,13 +1316,13 @@ void SwNoTextFrame::ImplPaintPictureGraphic( vcl::RenderContext* pOut,
             rGrfObj,
             aGrfAttr,
             aGraphicTransform,
-            nullptr == pGrfNd->GetFlyFormat() ? OUString() : pGrfNd->GetFlyFormat()->GetName(),
+            nullptr == pGrfNd->GetFlyFormat() ? OUString() : pGrfNd->GetFlyFormat()->GetName().toString(),
             rNoTNd.GetTitle(),
             rNoTNd.GetDescription());
     }
 }
 
-void SwNoTextFrame::ImplPaintPictureAnimate(vcl::RenderContext* pOut, SwViewShell* pShell,
+void SwNoTextFrame::ImplPaintPictureAnimate(vcl::RenderContext* pOut, const SwViewShell* pShell,
         SwGrfNode* pGrfNd, const SwRect& rAlignedGrfArea) const
 {
     OutputDevice* pVout;
@@ -1346,8 +1348,8 @@ void SwNoTextFrame::ImplPaintPictureAnimate(vcl::RenderContext* pOut, SwViewShel
                         pVout );
 }
 
-void SwNoTextFrame::ImplPaintPictureReplacement(const GraphicObject& rGrfObj, SwGrfNode* pGrfNd,
-        const SwRect& rAlignedGrfArea, SwViewShell* pShell) const
+void SwNoTextFrame::ImplPaintPictureReplacement(const GraphicObject& rGrfObj, const SwGrfNode* pGrfNd,
+        const SwRect& rAlignedGrfArea, const SwViewShell* pShell) const
 {
     TranslateId pResId;
 
@@ -1397,7 +1399,7 @@ void SwNoTextFrame::ImplPaintPictureBitmap( vcl::RenderContext* pOut,
                 SdrModel& rModel = pPage->getSdrModelFromSdrPage();
                 SdrOutliner& rOutl = rModel.GetDrawOutliner();
                 aOldBackColor = rOutl.GetBackgroundColor();
-                rOutl.SetBackgroundColor(pPage->GetPageBackgroundColor());
+                rOutl.SetBackgroundColor(pPage->GetPageBackgroundColor(nullptr, !bPrn));
             }
 
             bDone = paintUsingPrimitivesHelper(
