@@ -65,7 +65,7 @@ GetFlysAnchoredAt(SwDoc & rDoc, SwNodeOffset const nSttNode, bool const isAtPage
 
 //note: parameter is SwPam just so we can init SwUndRng, the End is ignored!
 SwUndoInserts::SwUndoInserts( SwUndoId nUndoId, const SwPaM& rPam )
-    : SwUndo( nUndoId, &rPam.GetDoc() )
+    : SwUndo( nUndoId, rPam.GetDoc() )
     , SwUndRng( rPam )
     , m_pTextFormatColl(nullptr)
     , m_pLastNodeColl(nullptr)
@@ -363,7 +363,7 @@ void SwUndoInserts::UndoImpl(::sw::UndoRedoContext & rContext)
             m_pTextFormatColl = static_cast<SwTextFormatColl*>(pTextNode->ChgFormatColl( m_pTextFormatColl )) ;
 
         m_pHistory->SetTmpEnd( m_nSetPos );
-        m_pHistory->TmpRollback(&rDoc, 0, false);
+        m_pHistory->TmpRollback(rDoc, 0, false);
     }
 }
 
@@ -442,7 +442,7 @@ void SwUndoInserts::RedoImpl(::sw::UndoRedoContext & rContext)
 
     // tdf#108124 the SwHistoryChangeFlyAnchor/SwHistoryFlyCnt must run before
     // m_FlyUndos as they were created by DelContentIndex()
-    m_pHistory->Rollback( &rDoc, m_nSetPos );
+    m_pHistory->Rollback( rDoc, m_nSetPos );
 
     // tdf#108124 (10/25/2017)
     // During UNDO we call SwUndoInsLayFormat::UndoImpl in reverse order,
