@@ -63,7 +63,7 @@
 #include <svx/hlnkitem.hxx>
 #include <sfx2/htmlmode.hxx>
 #include <editeng/langitem.hxx>
-#include <editeng/scripttypeitem.hxx>
+#include <editeng/scriptsetitem.hxx>
 #include <swundo.hxx>
 #include <doc.hxx>
 #include <viewopt.hxx>
@@ -96,8 +96,8 @@
 #include <swabstdlg.hxx>
 
 #include <comphelper/string.hxx>
+#include <comphelper/processfactory.hxx>
 #include <comphelper/propertysequence.hxx>
-#include <cppuhelper/bootstrap.hxx>
 
 #include <langhelper.hxx>
 
@@ -151,7 +151,7 @@ SfxUndoManager* SwAnnotationShell::GetUndoManager()
         OSL_ENSURE(pPostItMgr,"PostItMgr::Layout(): We are looping forever");
         return nullptr;
     }
-    return &pPostItMgr->GetActiveSidebarWin()->GetOutlinerView()->GetOutliner()->GetUndoManager();
+    return &pPostItMgr->GetActiveSidebarWin()->GetOutlinerView()->GetOutliner().GetUndoManager();
 }
 
 void SwAnnotationShell::Exec( SfxRequest &rReq )
@@ -359,13 +359,10 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
         break;
         case SID_SELECTALL:
         {
-            Outliner * pOutliner = pOLV->GetOutliner();
-            if(pOutliner)
-            {
-                sal_Int32 nParaCount = pOutliner->GetParagraphCount();
-                if (nParaCount > 0)
-                    pOLV->SelectRange(0, nParaCount );
-            }
+            Outliner& rOutliner = pOLV->GetOutliner();
+            sal_Int32 nParaCount = rOutliner.GetParagraphCount();
+            if (nParaCount > 0)
+                pOLV->SelectRange(0, nParaCount );
             break;
         }
         case FN_FORMAT_RESET:
@@ -377,7 +374,7 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
         case FN_SET_SUPER_SCRIPT:
         {
             SvxEscapementItem aItem(EE_CHAR_ESCAPEMENT);
-            SvxEscapement eEsc = static_cast<SvxEscapement>(aEditAttr.Get( EE_CHAR_ESCAPEMENT ).GetEnumValue());
+            SvxEscapement eEsc = aEditAttr.Get(EE_CHAR_ESCAPEMENT).GetEscapement();
 
             if( eEsc == SvxEscapement::Superscript )
                 aItem.SetEscapement( SvxEscapement::Off );
@@ -389,7 +386,7 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
         case FN_SET_SUB_SCRIPT:
         {
             SvxEscapementItem aItem(EE_CHAR_ESCAPEMENT);
-            SvxEscapement eEsc = static_cast<SvxEscapement>(aEditAttr.Get( EE_CHAR_ESCAPEMENT ).GetEnumValue());
+            SvxEscapement eEsc = aEditAttr.Get(EE_CHAR_ESCAPEMENT).GetEscapement();
 
             if( eEsc == SvxEscapement::Subscript )
                 aItem.SetEscapement( SvxEscapement::Off );
@@ -499,7 +496,7 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
                 FieldUnit eMetric = ::GetDfltMetric(dynamic_cast<SwWebView*>( pView) !=  nullptr );
                 SwModule::get()->PutItem(SfxUInt16Item(SID_ATTR_METRIC, eMetric));
                 */
-                SfxItemSetFixed<XATTR_FILLSTYLE, XATTR_FILLCOLOR, EE_ITEMS_START, EE_ITEMS_END> aDlgAttr(GetPool());
+                SfxItemSet aDlgAttr(SfxItemSet::makeFixedSfxItemSet<XATTR_FILLSTYLE, XATTR_FILLCOLOR, EE_ITEMS_START, EE_ITEMS_END>(GetPool()));
 
                 // util::Language does not exist in the EditEngine! Therefore not included in the set.
 
@@ -552,10 +549,9 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
                 FieldUnit eMetric = ::GetDfltMetric(dynamic_cast<SwWebView*>( pView) !=  nullptr );
                 SwModule::get()->PutItem(SfxUInt16Item(SID_ATTR_METRIC, eMetric));
                 */
-                SfxItemSetFixed<
-                        EE_ITEMS_START, EE_ITEMS_END,
-                        SID_ATTR_PARA_HYPHENZONE, SID_ATTR_PARA_WIDOWS>
-                    aDlgAttr( GetPool() );
+                SfxItemSet aDlgAttr(SfxItemSet::makeFixedSfxItemSet<
+                    EE_ITEMS_START, EE_ITEMS_END,
+                    SID_ATTR_PARA_HYPHENZONE, SID_ATTR_PARA_WIDOWS>(GetPool()));
 
                 aDlgAttr.Put(aEditAttr);
 
@@ -597,10 +593,9 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
                 if( !static_cast<const SfxBoolItem*>(pPoolItem)->GetValue() )
                     bLeftToRight = !bLeftToRight;
             }
-            SfxItemSetFixed<
-                    EE_PARA_WRITINGDIR, EE_PARA_WRITINGDIR,
-                    EE_PARA_JUST, EE_PARA_JUST>
-                aAttr( *aNewAttr.GetPool() );
+            SfxItemSet aAttr(SfxItemSet::makeFixedSfxItemSet<
+                EE_PARA_WRITINGDIR, EE_PARA_WRITINGDIR,
+                EE_PARA_JUST, EE_PARA_JUST>(*aNewAttr.GetPool()));
 
             SvxAdjust nAdjust = SvxAdjust::Left;
             if( const SvxAdjustItem* pAdjustItem = aEditAttr.GetItemIfSet(EE_PARA_JUST ) )
@@ -626,7 +621,7 @@ void SwAnnotationShell::Exec( SfxRequest &rReq )
     ExecPost(rReq, nEEWhich, aNewAttr, pOLV );
 }
 
-void SwAnnotationShell::ExecPost( SfxRequest& rReq, sal_uInt16 nEEWhich, SfxItemSet& rNewAttr, OutlinerView* pOLV )
+void SwAnnotationShell::ExecPost( const SfxRequest& rReq, sal_uInt16 nEEWhich, SfxItemSet& rNewAttr, OutlinerView* pOLV )
 {
     const SfxItemSet *pNewAttrs = rReq.GetArgs();
     const sal_uInt16 nSlot = rReq.GetSlot();
@@ -651,7 +646,7 @@ void SwAnnotationShell::ExecPost( SfxRequest& rReq, sal_uInt16 nEEWhich, SfxItem
         pOLV->SetAttribs(rNewAttr);
 
     m_rView.GetViewFrame().GetBindings().InvalidateAll(false);
-    if ( pOLV->GetOutliner()->IsModified() )
+    if ( pOLV->GetOutliner().IsModified() )
         m_rView.GetWrtShell().SetModified();
 }
 
@@ -864,7 +859,7 @@ void SwAnnotationShell::GetState(SfxItemSet& rSet)
                     rSet.DisableItem( nWhich );
                 else
                 {
-                    if(pOLV->GetOutliner() && pOLV->GetOutliner()->IsVertical())
+                    if (pOLV->GetOutliner().IsVertical())
                         rSet.DisableItem( nWhich );
                     else
                     {
@@ -1363,8 +1358,7 @@ void SwAnnotationShell::ExecLingu(SfxRequest &rReq)
         case SID_CHINESE_CONVERSION:
         {
                 //open ChineseTranslationDialog
-                Reference< XComponentContext > xContext(
-                    ::cppu::defaultBootstrap_InitialComponentContext() ); //@todo get context from calc if that has one
+                uno::Reference< uno::XComponentContext > xContext(::comphelper::getProcessComponentContext());
                 if(xContext.is())
                 {
                     Reference< lang::XMultiComponentFactory > xMCF( xContext->getServiceManager() );
@@ -1863,14 +1857,13 @@ void SwAnnotationShell::InsertSymbol(SfxRequest& rReq)
 
     // do not flicker
     pOLV->HideCursor();
-    Outliner * pOutliner = pOLV->GetOutliner();
-    pOutliner->SetUpdateLayout(false);
+    Outliner& rOutliner = pOLV->GetOutliner();
+    rOutliner.SetUpdateLayout(false);
 
     SfxItemSet aOldSet( pOLV->GetAttribs() );
-    SfxItemSetFixed<
-            EE_CHAR_FONTINFO, EE_CHAR_FONTINFO,
-            EE_CHAR_FONTINFO_CJK, EE_CHAR_FONTINFO_CTL>
-        aFontSet( *aOldSet.GetPool() );
+    SfxItemSet aFontSet(SfxItemSet::makeFixedSfxItemSet<
+        EE_CHAR_FONTINFO, EE_CHAR_FONTINFO, EE_CHAR_FONTINFO_CJK,
+        EE_CHAR_FONTINFO_CTL>(*aOldSet.GetPool()));
     aFontSet.Set( aOldSet );
 
     // Insert string
@@ -1878,8 +1871,8 @@ void SwAnnotationShell::InsertSymbol(SfxRequest& rReq)
 
     // Attributing (set font)
     SfxItemSet aSetFont( *aFontSet.GetPool(), aFontSet.GetRanges() );
-    SvxFontItem aFontItem (aFont.GetFamilyType(), aFont.GetFamilyName(),
-                            aFont.GetStyleName(), aFont.GetPitch(),
+    SvxFontItem aFontItem (aFont.GetFamilyTypeMaybeAskConfig(), aFont.GetFamilyName(),
+                            aFont.GetStyleName(), aFont.GetPitchMaybeAskConfig(),
                             aFont.GetCharSet(),
                             EE_CHAR_FONTINFO );
     SvtScriptType nScriptBreak = g_pBreakIt->GetAllScriptsOfText( sSym );
@@ -1906,7 +1899,7 @@ void SwAnnotationShell::InsertSymbol(SfxRequest& rReq)
     pOLV->SetAttribs( aFontSet );
 
     // From now on show it again
-    pOutliner->SetUpdateLayout(true);
+    rOutliner.SetUpdateLayout(true);
     pOLV->ShowCursor();
 
     rReq.AppendItem( SfxStringItem( SID_CHARMAP, sSym ) );
