@@ -40,9 +40,6 @@
 #include "../common/StatusHolder.h"
 #include "../common/os/path_utils.h"
 
-#define U_SHOW_CPLUSPLUS_API 0
-#define U_SHOW_CPLUSPLUS_HEADER_API 0
-
 #include <unicode/ustring.h>
 #include <unicode/utrans.h>
 #include <unicode/uchar.h>
